@@ -12,11 +12,11 @@ compare.models = function(...)
   L = length(models)
   model.names <- match.call()
   model.names <- as.character(model.names)[2:(L + 1)]
-  waic=unlist(lapply(models,function(x){x$WAIC}))
+  waic=unlist(lapply(models,function(x){x$WAIC$WAIC}))
   if (is.null(waic)){stop("MCMC samples do not contain WAIC values. Rerun 'nimbleMCMC()' setting the 'WAIC' argument to TRUE.")}
   deltaWAIC = waic - min(waic)
   w = exp(-0.5*deltaWAIC)/sum(exp(-0.5*deltaWAIC))
   res=data.frame(WAIC=waic,deltaWAIC=deltaWAIC,Weights=w,row.names=model.names)
   res = res[order(res$deltaWAIC),]
   return(res)
-}
\ No newline at end of file
+}
